searchData={"items":[{"type":"module","title":"LoggerTelegramBackend","doc":"A logger backend for [Telegram](https://telegram.org/).","ref":"LoggerTelegramBackend.html"},{"type":"module","title":"Usage - LoggerTelegramBackend","doc":"In your `c:Application.start/2` callback, add the `LoggerTelegramBackend`:\n\n    @impl true\n    def start(_type, _args) do\n      LoggerTelegramBackend.attach()\n\n      # ...\n    end\n\nAdd the following to your configuration:\n\n    config :logger, LoggerTelegramBackend,\n      chat_id: \"your_chat_id\",\n      token: \"yout_bot_token\"\n\nTo create a Telegram bot, see the next section.\n\n#","ref":"LoggerTelegramBackend.html#module-usage"},{"type":"module","title":"Creating a Telegram bot - LoggerTelegramBackend","doc":"To create a Telegram bot, follow the instructions\n[here](https://core.telegram.org/bots/features#creating-a-new-bot)  and get the `token` for the\nbot.\n\nThen send a message to the bot and get your `chat_id`:\n\n ```bash\n TOKEN=\"...\"\n curl https://api.telegram.org/bot$TOKEN/getUpdates\n ```","ref":"LoggerTelegramBackend.html#module-creating-a-telegram-bot"},{"type":"module","title":"Configuration - LoggerTelegramBackend","doc":"You can configure LoggerTelegramBackend through the application environment. Configure the\nfollowing options under the `LoggerTelegramBackend` key of the `:logger` application. For example,\nyou can do this in `config/runtime.exs`:\n\n    # config/runtime.exs\n    config :logger, LoggerTelegramBackend,\n      chat_id: System.fetch_env!(\"TELEGRAM_CHAT_ID\"),\n      token: System.fetch_env!(\"TELEGRAM_TOKEN\"),\n      level: :warning,\n      # ...\n\nThe basic configuration options are:\n\n- `:level` (`t:Logger.level/0`) - the level to be logged by this backend. Note that messages are\nfirst filtered by the general `:level` configuration for the `:logger` application. Defaults to\n`nil` (all levels are logged).\n\n- `:metadata` (list of `t:atom/0` or `:all`) - the metadata to be included in the message. `:all`\nwill get all metadata. Defaults to`[:line, :function, :module, :application, :file]`.\n\n- `:metadata_filter` (`t:keyword/0`, may also include `t:atom/0`) - the key-value pairs or keys\nthat is must be present in the metadata for a message to be sent. Defaults to `[]`. See the\n[*Filtering Messages* section](#filtering-messages) below.\n\nTo customize the behaviour of the HTTP client used by LoggerTelegramBackend, you can use these\noptions:\n\n- `:client` (`t:module/0`) - A module that implements the `LoggerTelegramBackend.HTTPClient`\nbehaviour. Defaults to `LoggerTelegramBackend.HTTPClient.Finch` (requires `:finch`).\n\n- `:client_pool_opts` (`t:keyword/0`) - Options to configure the HTTP client pool. See\n`Finch.start_link/1`. Defaults to `[]`.\n\n- `:client_request_opts` (`t:keyword/0`) - Options passed to the\n`c:LoggerTelegramBackend.HTTPClient.request/5` callback. See `Finch.request/3`. Defaults to `[]`.","ref":"LoggerTelegramBackend.html#module-configuration"},{"type":"module","title":"Filtering messages - LoggerTelegramBackend","doc":"If you would like to prevent LoggerTelegramBackend from sending certain messages, you can\nuse the `:metadata_filter` configuration option. It must be configured to be a list of key-value\npairs or keys.\n\n#","ref":"LoggerTelegramBackend.html#module-filtering-messages"},{"type":"module","title":"Examples - LoggerTelegramBackend","doc":"- `metadata_filter: [application: :core]` - The metadata must contain `application: :core`\n- `metadata_filter: [:user]` - The metadata must contain the key `:user`, but it can be set to any value\n- `metadata_filter: [{:application, :core}, :user]` - The metadata must contain `application:\n:core` **AND** must include the key `:user`","ref":"LoggerTelegramBackend.html#module-examples"},{"type":"module","title":"Using a proxy - LoggerTelegramBackend","doc":"An HTTP proxy can be configured via the `:client_pool_opts` option:\n\n    config :logger, LoggerTelegramBackend,\n      # ...\n      client_pool_opts: [conn_opts: [proxy: {:http, \"127.0.0.1\", 8888, []}]]\n\nSee the [Pool Configuration\nOptions](https://hexdocs.pm/finch/Finch.html#start_link/1-pool-configuration-options) for further\ninformation.","ref":"LoggerTelegramBackend.html#module-using-a-proxy"},{"type":"function","title":"LoggerTelegramBackend.attach/1","doc":"Adds the LoggerTelegramBackend backend.","ref":"LoggerTelegramBackend.html#attach/1"},{"type":"function","title":"Options - LoggerTelegramBackend.attach/1","doc":"* `:flush` - when `true`, guarantees all messages currently sent\n    to `Logger` are processed before the backend is added","ref":"LoggerTelegramBackend.html#attach/1-options"},{"type":"function","title":"Example - LoggerTelegramBackend.attach/1","doc":"iex> LoggerTelegramBackend.attach()\n    :ok","ref":"LoggerTelegramBackend.html#attach/1-example"},{"type":"function","title":"LoggerTelegramBackend.configure/1","doc":"Applies runtime configuration.\n\nSee the module doc for more information.","ref":"LoggerTelegramBackend.html#configure/1"},{"type":"function","title":"Example - LoggerTelegramBackend.configure/1","doc":"iex> LoggerTelegramBackend.configure(level: :error)\n    :ok","ref":"LoggerTelegramBackend.html#configure/1-example"},{"type":"function","title":"LoggerTelegramBackend.detach/1","doc":"Removes the LoggerTelegramBackend backend.","ref":"LoggerTelegramBackend.html#detach/1"},{"type":"function","title":"Options - LoggerTelegramBackend.detach/1","doc":"* `:flush` - when `true`, guarantees all messages currently sent\n    to `Logger` are processed before the backend is removed","ref":"LoggerTelegramBackend.html#detach/1-options"},{"type":"function","title":"Example - LoggerTelegramBackend.detach/1","doc":"iex> LoggerTelegramBackend.detach()\n    :ok","ref":"LoggerTelegramBackend.html#detach/1-example"},{"type":"behaviour","title":"LoggerTelegramBackend.HTTPClient","doc":"Specifies the API for using a custom HTTP Client.\n\nThe default HTTP client is `LoggerTelegramBackend.HTTPClient.Finch`.\n\nTo configure a different HTTP client, implement the `LoggerTelegramBackend.HTTPClient` behaviour\nand change the `:client` configuration:\n\n    config :logger, LoggerTelegramBackend,\n      client: MyHTTPClient","ref":"LoggerTelegramBackend.HTTPClient.html"},{"type":"behaviour","title":"Example - LoggerTelegramBackend.HTTPClient","doc":"A client implementation based on `:hackney` could look like this:\n\n    defmodule MyHTTPClient do\n      @behaviour LoggerTelegramBackend.HTTPClient\n\n      @hackney_pool_name :logger_telegram_backend_pool\n\n      @impl true\n      def child_spec(opts) do\n        :hackney_pool.child_spec(@hackney_pool_name, opts)\n      end\n\n      @impl true\n      def request(method, url, headers, body, opts) do\n        opts = Keyword.merge(opts, pool: @hackney_pool_name) ++ [:with_body]\n\n        case :hackney.request(method, url, headers, body, opts) do\n          {:ok, _status, _headers, _body} = result -> result\n          {:error, _reason} = error -> error\n        end\n      end\n    end","ref":"LoggerTelegramBackend.HTTPClient.html#module-example"},{"type":"callback","title":"LoggerTelegramBackend.HTTPClient.child_spec/1","doc":"Should return a **child specification** to start the HTTP client or `nil`.\n\nFor example, this can start a pool of HTTP connections dedicated to LoggerTelegramBackend.","ref":"LoggerTelegramBackend.HTTPClient.html#c:child_spec/1"},{"type":"callback","title":"LoggerTelegramBackend.HTTPClient.request/5","doc":"Should make an HTTP request to `url` with the given `method`, `headers`, `body` and `req_opts`.","ref":"LoggerTelegramBackend.HTTPClient.html#c:request/5"},{"type":"type","title":"LoggerTelegramBackend.HTTPClient.body/0","doc":"HTTP request or response body.","ref":"LoggerTelegramBackend.HTTPClient.html#t:body/0"},{"type":"type","title":"LoggerTelegramBackend.HTTPClient.headers/0","doc":"HTTP request or response headers.","ref":"LoggerTelegramBackend.HTTPClient.html#t:headers/0"},{"type":"type","title":"LoggerTelegramBackend.HTTPClient.method/0","doc":"HTTP request method.","ref":"LoggerTelegramBackend.HTTPClient.html#t:method/0"},{"type":"type","title":"LoggerTelegramBackend.HTTPClient.pool_opts/0","doc":"Options to configure the pool (set via `:client_pool_opts`).","ref":"LoggerTelegramBackend.HTTPClient.html#t:pool_opts/0"},{"type":"type","title":"LoggerTelegramBackend.HTTPClient.req_opts/0","doc":"HTTP request options (set via `:client_request_opts`).","ref":"LoggerTelegramBackend.HTTPClient.html#t:req_opts/0"},{"type":"type","title":"LoggerTelegramBackend.HTTPClient.status/0","doc":"HTTP response status.","ref":"LoggerTelegramBackend.HTTPClient.html#t:status/0"},{"type":"type","title":"LoggerTelegramBackend.HTTPClient.url/0","doc":"HTTP request URL.","ref":"LoggerTelegramBackend.HTTPClient.html#t:url/0"},{"type":"module","title":"LoggerTelegramBackend.HTTPClient.Finch","doc":"The built-in HTTP client, based on [finch](https://github.com/sneako/finch).\n\nIt client implements the `LoggerTelegramBackend.HTTPClient` behaviour.\n\nSee `LoggerTelegramBackend` for the available configuration options and\n`LoggerTelegramBackend.HTTPClient` if you wish to use another HTTP client.","ref":"LoggerTelegramBackend.HTTPClient.Finch.html"},{"type":"extras","title":"LoggerTelegramBackend","doc":"# LoggerTelegramBackend\n\n[![Build Status](https://github.com/adriankumpf/logger-telegram-backend/workflows/CI/badge.svg)](https://github.com/adriankumpf/logger-telegram-backend/actions)\n[![Docs](https://img.shields.io/badge/hex-docs-green.svg?style=flat)](https://hexdocs.pm/logger_telegram_backend)\n[![Hex.pm](https://img.shields.io/hexpm/v/logger_telegram_backend?color=%23714a94)](http://hex.pm/packages/logger_telegram_backend)\n\nA logger backend for [Telegram](https://telegram.org/).","ref":"readme.html"},{"type":"extras","title":"Installation - LoggerTelegramBackend","doc":"Add `:logger_telegram_backend` and `:finch` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:logger_telegram_backend, \"~> 3.0\"},\n    {:finch, \"~> 0.16\"},\n  ]\nend\n```\n\n#","ref":"readme.html#installation"},{"type":"extras","title":"Add the backend - LoggerTelegramBackend","doc":"In your `Application.start/2` callback, add the `LoggerTelegramBackend`:\n\n```elixir\n@impl true\ndef start(_type, _args) do\n  LoggerTelegramBackend.attach()\n\n  # ...\nend\n```\n\nAdd the following to your configuration:\n\n```elixir\nconfig :logger, LoggerTelegramBackend,\n  chat_id: \"your_chat_id\",\n  token: \"yout_bot_token\"\n```\n\nTo create a Telegram bot, see the next section.\n\n#","ref":"readme.html#add-the-backend"},{"type":"extras","title":"Configure the Telegram bot - LoggerTelegramBackend","doc":"To create a Telegram bot, follow the instructions [here](https://core.telegram.org/bots/features#creating-a-new-bot) and get the `token` for the bot.\n\nThen send a message to the bot and get your `chat_id`:\n\n```bash\nTOKEN=\"your_bot_token\"\ncurl https://api.telegram.org/bot$TOKEN/getUpdates\n```","ref":"readme.html#configure-the-telegram-bot"},{"type":"extras","title":"License - LoggerTelegramBackend","doc":"This project is Licensed under the [MIT License](LICENSE).","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n## [3.0.0] - 2023-08-12\n\n#","ref":"changelog.html"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"- Migrate built-in HTTP from `hackney` to `Finch`\n- Replace the`:adapter` with the `:client` option\n- Remove the `:proxy` option\n\n#","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Changes - Changelog","doc":"- Log a warning if sending fails\n- Allow messages to be filtered by a metadata key\n\n#","ref":"changelog.html#changes"},{"type":"extras","title":"Bug fixes - Changelog","doc":"- Escape metadata fields when sending messages\n- Fix deprecation warnings on Elixir 1.15\n\n#","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Upgrade Instructions - Changelog","doc":"##","ref":"changelog.html#upgrade-instructions"},{"type":"extras","title":"Dependencies - Changelog","doc":"Add `:finch` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:logger_telegram_backend, \"~> 3.0\"},\n    {:finch, \"~> 0.16\"},\n  ]\nend\n```\n\n##","ref":"changelog.html#dependencies"},{"type":"extras","title":"Adding the backend - Changelog","doc":"1. In your `Application.start/2` callback, add the `LoggerTelegramBackend` backend:\n\n   ```diff\n   def start(_type, _args) do\n   +  LoggerTelegramBackend.attach()\n   ```\n\n2. Remove the `:backends` configuration from `:logger`:\n\n   ```diff\n   config :logger,\n   - backends: [LoggerTelegramBackend, :console]\n   ```\n\n##","ref":"changelog.html#adding-the-backend"},{"type":"extras","title":"Config - Changelog","doc":"Configuration is now done via the `LoggerTelegramBackend` key:\n\n```diff\n- config :logger, :telegram,\n+ config :logger, LoggerTelegramBackend,\n    # ...\n```\n\n##","ref":"changelog.html#config"},{"type":"extras","title":"HTTP client (optional) - Changelog","doc":"1. Remove the `:adapter` configuration and\n2. Add the `:client` option and pass your own module that implements the `LoggerTelegramBackend.HTTPClient` behaviour\n\n   ```diff\n   config :logger, LoggerTelegramBackend,\n   -  adapter: {Tesla.Adapter.Gun, []}\n   +  client: MyGunAdapter\n   ```\n\n   See the documentation for `LoggerTelegramBackend.HTTPClient` for more information.\n\n##","ref":"changelog.html#http-client-optional"},{"type":"extras","title":"Proxy (optional) - Changelog","doc":"1. Remove the `:proxy` configuration\n2. Add the `:client_pool_opts` configuration\n\n   ```diff\n   config :logger, LoggerTelegramBackend,\n   -  proxy: \"socks5://127.0.0.1:9050\"\n   +  client_pool_opts: [conn_opts: [proxy: {:http, \"127.0.0.1\", 9050, []}]]\n   ```\n\n   See [Pool Configuration Options ](https://hexdocs.pm/finch/Finch.html#start_link/1-pool-configuration-options) for further information.\n\n## [2.0.1] - 2021-05-02\n\n#","ref":"changelog.html#proxy-optional"},{"type":"extras","title":"Fixed - Changelog","doc":"- Don't crash if sending an event does not succeed\n\n## [2.0.0] - 2020-12-22\n\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Changelog","doc":"- Use [tesla](https://github.com/teamon/tesla) to make the underlying HTTP client configurable\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"- Make hackney an optional dependency. To use the default `hackney` based adapter, add it to the list of dependencies:\n\n  ```elixir\n  def deps do\n    [\n      {:logger_telegram_backend, \"~> 2.0.0\"},\n      {:hackney, \"~> 1.17\"}\n    ]\n  end\n  ```\n\n## [1.3.0] - 2019-07-22\n\n#","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Changed - Changelog","doc":"- Respect maximum message length to avoid [MESSAGE_TOO_LONG errors](https://core.telegram.org/method/messages.sendMessage#return-errors)\n- Bump ex_doc from 0.20.2 to 0.21.1\n\n## [1.2.1] - 2019-05-27\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"- Bump httpoison from 1.4.0 to 1.5.1\n- Bump ex_doc from 0.19.1 to 0.20.2\n\n## [1.2.0] - 2018-11-28\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- Add proxy support (from [@mvalitov](https://github.com/mvalitov))\n\n## [1.1.0] - 2018-11-26\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Remove dependency on `Poison`: the success of a request is now solely determined by the HTTP status code.\n- Remove `GenStage` and simplify the overall event handling logic\n- Update dependencies\n\n## [1.0.3] - 2018-05-25\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- Add `@impl` attributes\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Update dependencies\n- Format code\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fix typo in README\n\n## [1.0.2] - 2018-03-01\n\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Changelog","doc":"- Update `httpoison` to 1.0\n\n## [1.0.1] - 2018-02-10\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"- Update Dependencies\n\n## [1.0.0] - 2018-01-14\n\n[3.0.0]: https://github.com/adriankumpf/logger-telegram-backend/compare/v2.0.1...v3.0.0\n[2.0.1]: https://github.com/adriankumpf/logger-telegram-backend/compare/v2.0.0...v2.0.1\n[2.0.0]: https://github.com/adriankumpf/logger-telegram-backend/compare/v1.3.0...v2.0.0\n[1.3.0]: https://github.com/adriankumpf/logger-telegram-backend/compare/v1.2.1...v1.3.0\n[1.2.1]: https://github.com/adriankumpf/logger-telegram-backend/compare/v1.2.0...v1.2.1\n[1.2.0]: https://github.com/adriankumpf/logger-telegram-backend/compare/v1.1.0...v1.2.0\n[1.1.0]: https://github.com/adriankumpf/logger-telegram-backend/compare/v1.0.3...v1.1.0\n[1.0.3]: https://github.com/adriankumpf/logger-telegram-backend/compare/v1.0.2...v1.0.3\n[1.0.2]: https://github.com/adriankumpf/logger-telegram-backend/compare/v1.0.1...v1.0.2\n[1.0.1]: https://github.com/adriankumpf/logger-telegram-backend/compare/v1.0.0...v1.0.1\n[1.0.0]: https://github.com/adriankumpf/logger-telegram-backend/compare/v0.1.0...v1.0.0","ref":"changelog.html#changed"}],"content_type":"text/markdown"}